@@ -23,11 +23,10 @@ class TestVariableInfo(unittest.TestCase):
 		for year in range(2010, 2019+1):
 			concepts = ['SEX BY AGE', 'MEDIAN AGE BY SEX', 'MEDIAN HOUSEHOLD INCOME IN THE PAST 12 MONTHS (IN {0} INFLATION-ADJUSTED DOLLARS)'.format(year)]
 			types = ['int', 'float', 'int']
-			if year == 2016: types = ['', 'int', 'int']
-			if year == 2017: types = ['', 'float', 'int']
 			inflation = 'inflation'
 			if year == 2014 or year == 2015: inflation = 'Inflation'
 			median_age_label = 'Estimate!!Median age!!Total'
+			if year == 2017: median_age_label = 'Estimate!!Median age --!!Total'
 			if year == 2018: median_age_label = 'Estimate!!Median age --!!Total'
 			if year == 2019: median_age_label = 'Estimate!!Median age --!!Total:'
 			total_label = 'Estimate!!Total'
@@ -75,8 +74,8 @@ class TestVariableInfo(unittest.TestCase):
 
 	def test_censusvar_acs3(self):
 		for year in range(2013, 2013+1):
-			expected = {'B19013_001E': ['B19013.  Median Household Income'.format(year),
-				'Median household income in the past 12 months (in {0} inflation-adjusted dollars)'.format(year), 'int']}
+			expected = {'B19013_001E': ['MEDIAN HOUSEHOLD INCOME IN THE PAST 12 MONTHS (IN {0} INFLATION-ADJUSTED DOLLARS)'.format(year),
+				'Estimate!!Median household income in the past 12 months (in {0} inflation-adjusted dollars)'.format(year), 'int']}
 			self.assertEqual(censusdata.censusvar('acs3', year, ['B19013_001E']), expected)
 
 	def test_censusvar_sf1(self):
@@ -613,12 +612,12 @@ class TestVariableInfo(unittest.TestCase):
 
 	def test_censustable_sf1(self):
 		expected = OrderedDict()
-		expected['P0020001'] = {'label': 'Total Population', 'concept': 'P2. Urban And Rural [6]', 'predicateType': ''}
-		expected['P0020002'] = {'label': 'Urban:', 'concept': 'P2. Urban And Rural [6]', 'predicateType': ''}
-		expected['P0020003'] = {'label': 'Urban: !! Inside urbanized areas', 'concept': 'P2. Urban And Rural [6]', 'predicateType': ''}
-		expected['P0020004'] = {'label': 'Urban: !! Inside urban clusters', 'concept': 'P2. Urban And Rural [6]', 'predicateType': ''}
-		expected['P0020005'] = {'label': 'Rural !! Inside urban clusters', 'concept': 'P2. Urban And Rural [6]', 'predicateType': ''}
-		expected['P0020006'] = {'label': 'Not defined for this file !! Inside urban clusters', 'concept': 'P2. Urban And Rural [6]', 'predicateType': ''}
+		expected['P002001'] = {'label': 'Total', 'concept': 'URBAN AND RURAL', 'predicateType': 'int'}
+		expected['P002002'] = {'label': 'Total!!Urban', 'concept': 'URBAN AND RURAL', 'predicateType': 'int'}
+		expected['P002003'] = {'label': 'Total!!Urban!!Inside urbanized areas', 'concept': 'URBAN AND RURAL', 'predicateType': 'int'}
+		expected['P002004'] = {'label': 'Total!!Urban!!Inside urban clusters', 'concept': 'URBAN AND RURAL', 'predicateType': 'int'}
+		expected['P002005'] = {'label': 'Total!!Rural', 'concept': 'URBAN AND RURAL', 'predicateType': 'int'}
+		expected['P002006'] = {'label': 'Total!!Not defined for this file', 'concept': 'URBAN AND RURAL', 'predicateType': 'int'}
 		self.assertEqual(censusdata.censustable('sf1', 2010, 'P002'), expected)
 
 	def test_unknowntable(self):
